﻿/*
* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
*
* Licensed under the Apache License, Version 2.0 (the "License").
* You may not use this file except in compliance with the License.
* A copy of the License is located at
*
*  http://aws.amazon.com/apache2.0
*
* or in the "license" file accompanying this file. This file is distributed
* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
* express or implied. See the License for the specific language governing
* permissions and limitations under the License.
*/

#include <aws/apigateway/model/LocationStatusType.h>
#include <aws/core/utils/HashingUtils.h>
#include <aws/core/Globals.h>
#include <aws/core/utils/EnumParseOverflowContainer.h>

using namespace Aws::Utils;


namespace Aws
{
  namespace APIGateway
  {
    namespace Model
    {
      namespace LocationStatusTypeMapper
      {

        static const int DOCUMENTED_HASH = HashingUtils::HashString("DOCUMENTED");
        static const int UNDOCUMENTED_HASH = HashingUtils::HashString("UNDOCUMENTED");


        LocationStatusType GetLocationStatusTypeForName(const Aws::String& name)
        {
          int hashCode = HashingUtils::HashString(name.c_str());
          if (hashCode == DOCUMENTED_HASH)
          {
            return LocationStatusType::DOCUMENTED;
          }
          else if (hashCode == UNDOCUMENTED_HASH)
          {
            return LocationStatusType::UNDOCUMENTED;
          }
          EnumParseOverflowContainer* overflowContainer = Aws::GetEnumOverflowContainer();
          if(overflowContainer)
          {
            overflowContainer->StoreOverflow(hashCode, name);
            return static_cast<LocationStatusType>(hashCode);
          }

          return LocationStatusType::NOT_SET;
        }

        Aws::String GetNameForLocationStatusType(LocationStatusType enumValue)
        {
          switch(enumValue)
          {
          case LocationStatusType::DOCUMENTED:
            return "DOCUMENTED";
          case LocationStatusType::UNDOCUMENTED:
            return "UNDOCUMENTED";
          default:
            EnumParseOverflowContainer* overflowContainer = Aws::GetEnumOverflowContainer();
            if(overflowContainer)
            {
              return overflowContainer->RetrieveOverflow(static_cast<int>(enumValue));
            }

            return {};
          }
        }

      } // namespace LocationStatusTypeMapper
    } // namespace Model
  } // namespace APIGateway
} // namespace Aws
