﻿/*
* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
*
* Licensed under the Apache License, Version 2.0 (the "License").
* You may not use this file except in compliance with the License.
* A copy of the License is located at
*
*  http://aws.amazon.com/apache2.0
*
* or in the "license" file accompanying this file. This file is distributed
* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
* express or implied. See the License for the specific language governing
* permissions and limitations under the License.
*/

#include <aws/config/model/ResourceValue.h>
#include <aws/core/utils/json/JsonSerializer.h>

#include <utility>

using namespace Aws::Utils::Json;
using namespace Aws::Utils;

namespace Aws
{
namespace ConfigService
{
namespace Model
{

ResourceValue::ResourceValue() : 
    m_value(ResourceValueType::NOT_SET),
    m_valueHasBeenSet(false)
{
}

ResourceValue::ResourceValue(JsonView jsonValue) : 
    m_value(ResourceValueType::NOT_SET),
    m_valueHasBeenSet(false)
{
  *this = jsonValue;
}

ResourceValue& ResourceValue::operator =(JsonView jsonValue)
{
  if(jsonValue.ValueExists("Value"))
  {
    m_value = ResourceValueTypeMapper::GetResourceValueTypeForName(jsonValue.GetString("Value"));

    m_valueHasBeenSet = true;
  }

  return *this;
}

JsonValue ResourceValue::Jsonize() const
{
  JsonValue payload;

  if(m_valueHasBeenSet)
  {
   payload.WithString("Value", ResourceValueTypeMapper::GetNameForResourceValueType(m_value));
  }

  return payload;
}

} // namespace Model
} // namespace ConfigService
} // namespace Aws
