﻿/*
* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
*
* Licensed under the Apache License, Version 2.0 (the "License").
* You may not use this file except in compliance with the License.
* A copy of the License is located at
*
*  http://aws.amazon.com/apache2.0
*
* or in the "license" file accompanying this file. This file is distributed
* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
* express or implied. See the License for the specific language governing
* permissions and limitations under the License.
*/

#include <aws/rds-data/model/SqlStatementResult.h>
#include <aws/core/utils/json/JsonSerializer.h>

#include <utility>

using namespace Aws::Utils::Json;
using namespace Aws::Utils;

namespace Aws
{
namespace RDSDataService
{
namespace Model
{

SqlStatementResult::SqlStatementResult() : 
    m_numberOfRecordsUpdated(0),
    m_numberOfRecordsUpdatedHasBeenSet(false),
    m_resultFrameHasBeenSet(false)
{
}

SqlStatementResult::SqlStatementResult(JsonView jsonValue) : 
    m_numberOfRecordsUpdated(0),
    m_numberOfRecordsUpdatedHasBeenSet(false),
    m_resultFrameHasBeenSet(false)
{
  *this = jsonValue;
}

SqlStatementResult& SqlStatementResult::operator =(JsonView jsonValue)
{
  if(jsonValue.ValueExists("numberOfRecordsUpdated"))
  {
    m_numberOfRecordsUpdated = jsonValue.GetInt64("numberOfRecordsUpdated");

    m_numberOfRecordsUpdatedHasBeenSet = true;
  }

  if(jsonValue.ValueExists("resultFrame"))
  {
    m_resultFrame = jsonValue.GetObject("resultFrame");

    m_resultFrameHasBeenSet = true;
  }

  return *this;
}

JsonValue SqlStatementResult::Jsonize() const
{
  JsonValue payload;

  if(m_numberOfRecordsUpdatedHasBeenSet)
  {
   payload.WithInt64("numberOfRecordsUpdated", m_numberOfRecordsUpdated);

  }

  if(m_resultFrameHasBeenSet)
  {
   payload.WithObject("resultFrame", m_resultFrame.Jsonize());

  }

  return payload;
}

} // namespace Model
} // namespace RDSDataService
} // namespace Aws
