﻿/*
* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
*
* Licensed under the Apache License, Version 2.0 (the "License").
* You may not use this file except in compliance with the License.
* A copy of the License is located at
*
*  http://aws.amazon.com/apache2.0
*
* or in the "license" file accompanying this file. This file is distributed
* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
* express or implied. See the License for the specific language governing
* permissions and limitations under the License.
*/

#include <aws/ssm/model/PatchOperationType.h>
#include <aws/core/utils/HashingUtils.h>
#include <aws/core/Globals.h>
#include <aws/core/utils/EnumParseOverflowContainer.h>

using namespace Aws::Utils;


namespace Aws
{
  namespace SSM
  {
    namespace Model
    {
      namespace PatchOperationTypeMapper
      {

        static const int Scan_HASH = HashingUtils::HashString("Scan");
        static const int Install_HASH = HashingUtils::HashString("Install");


        PatchOperationType GetPatchOperationTypeForName(const Aws::String& name)
        {
          int hashCode = HashingUtils::HashString(name.c_str());
          if (hashCode == Scan_HASH)
          {
            return PatchOperationType::Scan;
          }
          else if (hashCode == Install_HASH)
          {
            return PatchOperationType::Install;
          }
          EnumParseOverflowContainer* overflowContainer = Aws::GetEnumOverflowContainer();
          if(overflowContainer)
          {
            overflowContainer->StoreOverflow(hashCode, name);
            return static_cast<PatchOperationType>(hashCode);
          }

          return PatchOperationType::NOT_SET;
        }

        Aws::String GetNameForPatchOperationType(PatchOperationType enumValue)
        {
          switch(enumValue)
          {
          case PatchOperationType::Scan:
            return "Scan";
          case PatchOperationType::Install:
            return "Install";
          default:
            EnumParseOverflowContainer* overflowContainer = Aws::GetEnumOverflowContainer();
            if(overflowContainer)
            {
              return overflowContainer->RetrieveOverflow(static_cast<int>(enumValue));
            }

            return {};
          }
        }

      } // namespace PatchOperationTypeMapper
    } // namespace Model
  } // namespace SSM
} // namespace Aws
